==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/pt-BR/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Ativo verificado em',
    'Accessory_Checkout_Notification' => 'Acessório verificado',
    'Asset_Checkin_Notification' => 'Ativo verificado em',
    'Asset_Checkout_Notification' => 'Ativo retornado',
    'Confirm_Accessory_Checkin' => 'Confirme a devolução do acessório',
    'Confirm_Asset_Checkin' => 'Confirme a devolução do ativo',
    'Confirm_accessory_delivery' => 'Confirme a entrega do acessório',
    'Confirm_asset_delivery' => 'Confirme a entrega do ativo',
    'Confirm_consumable_delivery' => 'Confirme a entrega de consumíveis',
    'Confirm_license_delivery' => 'Confirme a entrega de licença',
    'Consumable_checkout_notification' => 'Consumível verificado',
    'Days' => 'Dias',
    'Expected_Checkin_Date' => 'Um ativo disponibilizado a você deve ser retornado em :date',
    'Expected_Checkin_Notification' => 'Lembrete: :name prazo de devolução aproximando',
    'Expected_Checkin_Report' => 'Relatório de check-in de ativos esperado',
    'Expiring_Assets_Report' => 'Relatório de ativos expirando.',
    'Expiring_Licenses_Report' => 'Relatório de Licenças a expirar.',
    'Item_Request_Canceled' => 'Requisição de item cancelado',
    'Item_Requested' => 'Item requisitado',
    'License_Checkin_Notification' => 'Licença verificada em',
    'License_Checkout_Notification' => 'Licença registrada',
    'Low_Inventory_Report' => 'Relatório de baixas de inventario',
    'a_user_canceled' => 'Um usuário cancelou uma requisição no website',
    'a_user_requested' => 'Um usuário requisitou um item no website',
    'acceptance_asset_accepted' => 'Um usuário aceitou um item',
    'acceptance_asset_declined' => 'Um usuário recusou um item',
    'accessory_name' => 'Nome do Acessório',
    'additional_notes' => 'Comentários adicionais',
    'admin_has_created' => 'Um administrador criou uma conta para você em :web.',
    'asset' => 'Ativo',
    'asset_name' => 'Nome do Ativo',
    'asset_requested' => 'Requisição de Ativo',
    'asset_tag' => 'Etiqueta de Ativo',
    'assets_warrantee_alert' => 'Há um :count ativo com a garantia expirando nos próximos :threshold dias. Existem :count ativos com a garantia expirando nos próximos :threshold dias.',
    'assigned_to' => 'Atribuído a',
    'best_regards' => 'Atenciosamente,',
    'canceled' => 'Cancelado',
    'checkin_date' => 'Data de devolução',
    'checkout_date' => 'Data de saída',
    'checkedout_from' => 'Disponibilizado de',
    'checkedin_from'  => 'Check-in de',
    'checked_into' => 'Check-in em',
    'click_on_the_link_accessory' => 'Por favor clique no link na parte inferior para confirmar que recebeu o acessório.',
    'click_on_the_link_asset' => 'Por favor clique no link na parte inferior para confirmar que recebeu o ativo.',
    'click_to_confirm' => 'Por favor clique no link a seguir para confirmar sua conta :web:',
    'current_QTY' => 'Qtde. atual',
    'days' => 'Dias',
    'expecting_checkin_date' => 'Excedeu a data dar entrada',
    'expires' => 'Expira',
    'hello' => 'Olá',
    'hi' => 'Oi',
    'i_have_read' => 'Li e concordo com os termos de uso e recebi este item.',
    'inventory_report' => 'Relatório de Inventário',
    'item' => 'Item',
    'item_checked_reminder' => 'Este é um lembrete que você tem atualmente :count itens check-out para você que você não aceitou ou recusou. Por favor, clique no link abaixo para confirmar sua decisão.',
    'license_expiring_alert' => 'Há uma :count licença expirando nos próximos :threshold dias. | Existem :count licenças expirand nos próximos :threshold dias.',
    'link_to_update_password' => 'Por favor clique no link abaixo para atualizar a sua senha do :web:',
    'login' => 'Login:',
    'login_first_admin' => 'Faça login na sua instalação do Snipe-IT usando os dados abaixo:',
    'low_inventory_alert' => 'Há um :count que está abaixo do estoque mínimo ou em breve estará abaixo. | Existem :count items que estão abaixo do estoque mínimo ou em breve estarão baixos.',
    'min_QTY' => 'Qtde. Min',
    'name' => 'Nome',
    'new_item_checked' => 'Um novo item foi atribuído em seu nome, os detalhes estão abaixo.',
    'notes' => 'Notas',
    'password' => 'Senha',
    'password_reset' => 'Redefinir Senha',
    'read_the_terms' => 'Por favor, leia os termos de uso abaixo.',
    'read_the_terms_and_click' => 'Por favor, leia os termos de uso abaixo, e clique no link na parte inferior para confirmar que você leu e concorda com os termos de uso, e recebeu o ativo.',
    'requested' => 'Solicitado',
    'reset_link' => 'Seu Link de redefinição da senha',
    'reset_password' => 'Clique aqui para redefinir sua senha:',
    'rights_reserved' => 'Todos os direitos reservados.',
    'serial' => 'Nº de Série',
    'snipe_webhook_test' => 'Teste de Integração Snipe-IT',
    'snipe_webhook_summary' => 'Resumo de Teste de Integração Snipe-IT',
    'supplier' => 'Fornecedor',
    'tag' => 'Etiqueta',
    'test_email' => 'Email de teste do Snipe-IT',
    'test_mail_text' => 'Isto é um e-mail de teste do Snipe-IT Asset Management System. Se você recebeu essa mensagem, quer dizer que o e-mail está funcionando :)',
    'the_following_item' => 'O Item a seguir foi devolvido: ',
    'to_reset' => 'Para fazer reset da senha do :web, preencha este formulário:',
    'type' => 'Tipo',
    'upcoming-audits' => 'Existe um :count ativo que está sendo auditado dentro de :threshold days. There are :count assets que estão sendo enviados para auditoria dentro de :threshold dias.',
    'user' => 'Usuário',
    'username' => 'Nome de Usuário',
    'unaccepted_asset_reminder' => 'Você tem Ativos não Aceitos.',
    'welcome' => 'Bem-vindo(a), :name',
    'welcome_to' => 'Bem-vindo ao :web!',
    'your_assets' => 'Ver seus ativos',
    'your_credentials' => 'Suas credenciais do Snipe-IT',
    'mail_sent' => 'Email enviado com sucesso!',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/pt-BR/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Ativo verificado em',
    'Accessory_Checkout_Notification' => 'Accessory checked out|:count Accessories checked out',
    'Asset_Checkin_Notification' => 'Asset checked in: :tag',
    'Asset_Checkout_Notification' => 'Asset checked out: :tag',
    'Confirm_Accessory_Checkin' => 'Confirme a devolução do acessório',
    'Confirm_Asset_Checkin' => 'Confirme a devolução do ativo',
    'Confirm_component_checkin' => 'Component checkin confirmation',
    'Confirm_accessory_delivery' => 'Confirme a entrega do acessório',
    'Confirm_asset_delivery' => 'Confirme a entrega do ativo',
    'Confirm_consumable_delivery' => 'Confirme a entrega de consumíveis',
    'Confirm_component_delivery' => 'Component delivery confirmation',
    'Confirm_license_delivery' => 'Confirme a entrega de licença',
    'Consumable_checkout_notification' => 'Consumível verificado',
    'Component_checkout_notification' => 'Component checked out',
    'Component_checkin_notification' => 'Component checked in',
    'Days' => 'Dias',
    'Expected_Checkin_Date' => 'Um ativo disponibilizado a você deve ser retornado em :date',
    'Expected_Checkin_Notification' => 'Lembrete: :name prazo de devolução aproximando',
    'Expected_Checkin_Report' => 'Relatório de check-in de ativos esperado',
    'Expiring_Assets_Report' => 'Relatório de ativos expirando',
    'Expiring_Licenses_Report' => 'Relatório de Licenças a expirar',
    'Item_Request_Canceled' => 'Requisição de item cancelado',
    'Item_Requested' => 'Item requisitado',
    'License_Checkin_Notification' => 'Licença verificada em',
    'License_Checkout_Notification' => 'Licença registrada',
    'license_for'   => 'License for',
    'Low_Inventory_Report' => 'Relatório de baixas de inventario',
    'a_user_canceled' => 'Um usuário cancelou uma requisição no website',
    'a_user_requested' => 'Um usuário requisitou um item no website',
    'acceptance_asset_accepted_to_user' => 'You have accepted an item assigned to you by :site_name|You have accepted :qty items assigned to you by :site_name',
    'acceptance_asset_accepted' => 'Um usuário aceitou um item',
    'acceptance_asset_declined' => 'Um usuário recusou um item',
    'send_pdf_copy' => 'Send a copy of this acceptance to my email address',
    'accessory_name' => 'Nome do Acessório',
    'additional_notes' => 'Comentários adicionais',
    'admin_has_created' => 'An administrator has created an account for you on the :web website. Please find your username below, and click on the link to set a password.',
    'asset' => 'Ativo',
    'asset_name' => 'Nome do Ativo',
    'asset_requested' => 'Requisição de Ativo',
    'asset_tag' => 'Etiqueta de Ativo',
    'assets_warrantee_alert' => 'There is :count asset with an expiring warranty or that are reaching their end of life in the next :threshold days.|There are :count assets with expiring warranties or that are reaching their end of life in the next :threshold days.',
    'assigned_to' => 'Atribuído a',
    'eol' => 'EOL',
    'best_regards' => 'Atenciosamente,',
    'canceled' => 'Cancelado',
    'checkin_date' => 'Data de devolução',
    'checkout_date' => 'Data de saída',
    'checkedout_from' => 'Disponibilizado de',
    'checkedin_from'  => 'Check-in de',
    'checked_into' => 'Check-in em',
    'click_on_the_link_accessory' => 'Por favor clique no link na parte inferior para confirmar que recebeu o acessório.',
    'click_on_the_link_asset' => 'Por favor clique no link na parte inferior para confirmar que recebeu o ativo.',
    'click_to_confirm' => 'Por favor clique no link a seguir para confirmar sua conta :web:',
    'current_QTY' => 'Qtde. atual',
    'days' => 'Dias',
    'expecting_checkin_date' => 'Excedeu a data dar entrada',
    'expires' => 'Expira',
    'terminates' => 'Terminates',
    'following_accepted' => 'The following was accepted',
    'following_declined' => 'The following was declined',
    'hello' => 'Olá',
    'hi' => 'Oi',
    'i_have_read' => 'Li e concordo com os termos de uso e recebi este item.',
    'initiated_accepted' => 'A checkout you initiated was accepted',
    'initiated_declined' => 'A checkout you initiated was declined',
    'inventory_report' => 'Relatório de Inventário',
    'item' => 'Item',
    'item_checked_reminder' => 'Este é um lembrete que você tem atualmente :count itens check-out para você que você não aceitou ou recusou. Por favor, clique no link abaixo para confirmar sua decisão.',
    'license_expiring_alert' => 'There is :count license expiring or terminating in the next :threshold days.|There are :count licenses expiring or terminating in the next :threshold days.',
    'link_to_update_password' => 'Por favor clique no link abaixo para atualizar a sua senha do :web:',
    'login' => 'Entrar',
    'login_first_admin' => 'Faça login na sua instalação do Snipe-IT usando os dados abaixo:',
    'low_inventory_alert' => 'Há um :count que está abaixo do estoque mínimo ou em breve estará abaixo. | Existem :count items que estão abaixo do estoque mínimo ou em breve estarão baixos.',
    'min_QTY' => 'Qtde. Min',
    'name' => 'Nome',
    'new_item_checked' => 'A new item has been checked out under your name, details are below.|:count new items have been checked out under your name, details are below.',
    'new_item_checked_with_acceptance' => 'A new item has been checked out under your name that requires acceptance, details are below.|:count new items have been checked out under your name that requires acceptance, details are below.',
    'new_item_checked_location' => 'A new item has been checked out to :location, details are below.|:count new items have been checked out to :location, details are below.',
    'recent_item_checked' => 'Um novo item foi registrado em seu nome que requer aceitação, detalhes abaixo.',
    'notes' => 'Notas',
    'password' => 'Senha',
    'password_reset' => 'Redefinir Senha',
    'read_the_terms' => 'Por favor, leia os termos de uso abaixo.',
    'read_the_terms_and_click' => 'Por favor, leia os termos de uso abaixo, e clique no link na parte inferior para confirmar que você leu e concorda com os termos de uso, e recebeu o ativo.',
    'requested' => 'Solicitado',
    'reset_link' => 'Seu Link de redefinição da senha',
    'reset_password' => 'Clique aqui para redefinir sua senha:',
    'rights_reserved' => 'Todos os direitos reservados.',
    'serial' => 'Nº de Série',
    'snipe_webhook_test' => 'Teste de Integração Snipe-IT',
    'snipe_webhook_summary' => 'Resumo de Teste de Integração Snipe-IT',
    'supplier' => 'Fornecedor',
    'tag' => 'Etiqueta',
    'test_email' => 'Email de teste do Snipe-IT',
    'test_mail_text' => 'Isto é um e-mail de teste do Snipe-IT Asset Management System. Se você recebeu essa mensagem, quer dizer que o e-mail está funcionando :)',
    'the_following_item' => 'O Item a seguir foi devolvido: ',
    'to_reset' => 'Para fazer reset da senha do :web, preencha este formulário:',
    'type' => 'Tipo',
    'upcoming-audits' => 'Existe um :count ativo que está sendo auditado dentro de :threshold days. There are :count assets que estão sendo enviados para auditoria dentro de :threshold dias.',
    'user' => 'Usuário',
    'username' => 'Nome de Usuário',
    'unaccepted_asset_reminder' => 'Reminder: You have Unaccepted Assets.',
    'welcome' => 'Bem-vindo(a), :name',
    'welcome_to' => 'Bem-vindo ao :web!',
    'your_assets' => 'Ver seus ativos',
    'your_credentials' => 'Suas credenciais do Snipe-IT',
    'mail_sent' => 'Email enviado com sucesso!',
];
